# Generated by Django 3.2.14 on 2022-07-11 22:08

from django.db import migrations, models


class Migration(migrations.Migration):

    dependencies = [
        ('findmydevice', '0001_initial'),
    ]

    operations = [
        migrations.AlterField(
            model_name='location',
            name='raw_date',
            field=models.PositiveBigIntegerField(),
        ),
    ]
