{% extends "admin/base_site.html" %}
{% load i18n static %}

{% block extrahead %}{{ block.super }}
    <meta name="google" content="notranslate">
    <meta name="robots" content="noindex,nofollow" />
{% endblock %}

{% block footer %}
<div id="footer" class="submit-row">
    <a href="https://gitlab.com/jedie/django-find-my-device">gitlab.com/jedie/django-find-my-device</a>
</div>
{% endblock %}