# Generated by Django 3.2.14 on 2022-07-19 17:04

from django.db import migrations, models


class Migration(migrations.Migration):

    dependencies = [
        ('findmydevice', '0006_push_commands'),
    ]

    operations = [
        migrations.AlterField(
            model_name='device',
            name='command2user',
            field=models.CharField(blank=True, editable=False, max_length=128, null=True),
        ),
        migrations.AlterField(
            model_name='device',
            name='hashed_password',
            field=models.CharField(editable=False, max_length=64),
        ),
        migrations.AlterField(
            model_name='device',
            name='privkey',
            field=models.CharField(editable=False, max_length=2048, unique=True),
        ),
        migrations.AlterField(
            model_name='device',
            name='pubkey',
            field=models.CharField(editable=False, max_length=512, unique=True),
        ),
    ]
