# Generated by Django 3.2.14 on 2022-07-12 09:56

from django.db import migrations, models


class Migration(migrations.Migration):

    dependencies = [
        ('findmydevice', '0003_rename_deviceuser_device'),
    ]

    operations = [
        migrations.AddField(
            model_name='device',
            name='name',
            field=models.CharField(blank=True, help_text='Optional Name for this Device. e.g.: Username ;) Just displayed in the admin', max_length=64, null=True),
        ),
    ]
