* {
    font-family: 'Gill Sans', 'Gill Sans MT', Calibri, 'Trebuchet MS', sans-serif;
}
body {
    background-color: #232323;
    height: 98%;
}

html{
    height: 100%;
}

h2, h3{
    color: #4cb050;
    margin: 10px;
}

p, a, label{
    color:whitesmoke;
    margin: 10px;
    display:inline;
}

input {
    margin: 10px;
    position: center;
    background-color: #232323;
    color: whitesmoke;
    font-size: medium;
    padding: 10px;
    border-top: none;
    border-left: none;
    border-right: none;
    border-radius: 0px;
    border-color: whitesmoke;
}

input:focus {
    border-color: #4cb050;
    outline: none;
}

button {
    text-align: center;
    background-color: #4cb050;
    color: #232323;
    border: none;
    border-radius: 8px;
    height: 5%;
    padding: 10px;
    margin: 8px;
    font-size: medium; 
}

.imageButton{
    padding: 5px;
}

button:active {
    background-color: #318f2f;
}

footer{
    padding: 10px;
    z-index: 2;
}

.center{
    width: 100%;
    border: 1px solid black;
    display: flex;
    align-items: center;
    justify-content: center;
    border: none;
}

.column-left {
    float:left;
    width:20%;
  }

.column-middle{
    float:left;
    width:80%;
}

.row:after {
    content: "";
    display: table;
    clear: both;
}

#locateButton{
    width: 50%;
}

#dataView{
    margin-top: 20px;
    height: 64%;
}

#map{
    width: 99%;
    height: 64%;
    position: absolute;
    z-index: 1;
}

.deviceInfo{
    width:97%;
    padding: 1vw;
    margin-top: 2vw;
    background-color: #303030;
    border-radius: 5vw;
    border-color: #252525;
    display: none;
    opacity: 0.5;
}

#passwordPrompt{
    background-color: #232323;
    border-style: solid;
    border-color:  #4cb050;
    border-width: 1px;
    border-radius: 8px;
    padding: 10px;
    position: absolute;
    z-index: 1;
    top:50%;
    left:50%;
    opacity: 0.9;
    transform:translate(-50%, -50%);
}

#imagePrompt{
    background-color: #232323;
    border-style: solid;
    border-color:  #4cb050;
    border-width: 1px;
    border-radius: 8px;
    padding: 10px;
    position: absolute;
    z-index: 1;
    top:50%;
    left:50%;
    transform:translate(-50%, -50%);
}

#imageFromDevice{
    width: 75%;
}