# Generated by Django 3.2.14 on 2022-07-19 14:15

from django.db import migrations, models


class Migration(migrations.Migration):

    dependencies = [
        ('findmydevice', '0004_device_name'),
    ]

    operations = [
        migrations.AddField(
            model_name='device',
            name='user_agent',
            field=models.CharField(blank=True, editable=False, max_length=512, null=True),
        ),
        migrations.AddField(
            model_name='location',
            name='user_agent',
            field=models.CharField(blank=True, editable=False, max_length=512, null=True),
        ),
    ]
