# Generated by Django 3.2.14 on 2022-07-12 09:33

from django.db import migrations


class Migration(migrations.Migration):

    dependencies = [
        ('findmydevice', '0002_alter_location_raw_date'),
    ]

    operations = [
        migrations.RenameModel(
            old_name='DeviceUser',
            new_name='Device',
        ),
        migrations.RenameField(
            model_name='location',
            old_name='device_user',
            new_name='device',
        ),
    ]
