# Generated by Django 3.2.14 on 2022-07-31 15:41

import django.core.validators
from django.db import migrations, models

from findmydevice.models.device import get_short_id


class Migration(migrations.Migration):

    dependencies = [
        ('findmydevice', '0007_editable'),
    ]

    operations = [
        migrations.AddField(
            model_name='device',
            name='short_id',
            field=models.CharField(
                db_index=True,
                default=get_short_id,  # can collide in very, very rare cases ;)
                editable=False,
                help_text='Device ID used for the App and Web page to identify this device',
                max_length=6,
                unique=True,
                validators=[django.core.validators.MinLengthValidator(6)],
            ),
            preserve_default=False,
        ),
    ]
