# Generated by Django 3.2.14 on 2022-07-19 16:29

from django.db import migrations, models


class Migration(migrations.Migration):

    dependencies = [
        ('findmydevice', '0005_user_agent'),
    ]

    operations = [
        migrations.AddField(
            model_name='device',
            name='command2user',
            field=models.CharField(blank=True, max_length=128, null=True),
        ),
        migrations.AddField(
            model_name='device',
            name='push_url',
            field=models.URLField(
                blank=True, help_text='Push notification URL (Set by FMD app)', null=True
            ),
        ),
    ]
