# Generated by Django 3.2.15 on 2022-08-06 17:56

from django.db import migrations, models


class Migration(migrations.Migration):

    dependencies = [
        ('findmydevice', '0008_device_short_id'),
    ]

    operations = [
        migrations.AlterField(
            model_name='device',
            name='privkey',
            field=models.CharField(editable=False, max_length=4096, unique=True),
        ),
        migrations.AlterField(
            model_name='device',
            name='pubkey',
            field=models.CharField(editable=False, max_length=1024, unique=True),
        ),
    ]
